# -*- coding: utf-8 -*-

# PLEASE DO NOT EDIT THIS FILE, IT IS GENERATED AND WILL BE OVERWRITTEN:
# https://github.com/ccxt/ccxt/blob/master/CONTRIBUTING.md#how-to-contribute-code

from ccxt.binance import binance


class binanceusdm(binance):

    def describe(self):
        return self.deep_extend(super(binanceusdm, self).describe(), {
            'id': 'binanceusdm',
            'name': 'Binance USDⓈ-M',
            'urls': {
                'logo': 'https://user-images.githubusercontent.com/1294454/117738721-668c8d80-b205-11eb-8c49-3fad84c4a07f.jpg',
            },
            'options': {
                'defaultType': 'future',
            },
            # https://www.binance.com/en/fee/futureFee
            'fees': {
                'trading': {
                    'tierBased': True,
                    'percentage': True,
                    'taker': self.parse_number('0.000400'),
                    'maker': self.parse_number('0.000200'),
                    'tiers': {
                        'taker': [
                            [self.parse_number('0'), self.parse_number('0.000400')],
                            [self.parse_number('250'), self.parse_number('0.000400')],
                            [self.parse_number('2500'), self.parse_number('0.000350')],
                            [self.parse_number('7500'), self.parse_number('0.000320')],
                            [self.parse_number('22500'), self.parse_number('0.000300')],
                            [self.parse_number('50000'), self.parse_number('0.000270')],
                            [self.parse_number('100000'), self.parse_number('0.000250')],
                            [self.parse_number('200000'), self.parse_number('0.000220')],
                            [self.parse_number('400000'), self.parse_number('0.000200')],
                            [self.parse_number('750000'), self.parse_number('0.000170')],
                        ],
                        'maker': [
                            [self.parse_number('0'), self.parse_number('0.000200')],
                            [self.parse_number('250'), self.parse_number('0.000160')],
                            [self.parse_number('2500'), self.parse_number('0.000140')],
                            [self.parse_number('7500'), self.parse_number('0.000120')],
                            [self.parse_number('22500'), self.parse_number('0.000100')],
                            [self.parse_number('50000'), self.parse_number('0.000080')],
                            [self.parse_number('100000'), self.parse_number('0.000060')],
                            [self.parse_number('200000'), self.parse_number('0.000040')],
                            [self.parse_number('400000'), self.parse_number('0.000020')],
                            [self.parse_number('750000'), self.parse_number('0')],
                        ],
                    },
                },
            },
        })

    def fetch_trading_fees(self, params={}):
        self.load_markets()
        marketSymbols = list(self.markets.keys())
        fees = {}
        accountInfo = self.fapiPrivateGetAccount(params)
        # {
        #     "feeTier": 0,       # account commisssion tier
        #     "canTrade": True,   # if can trade
        #     "canDeposit": True,     # if can transfer in asset
        #     "canWithdraw": True,    # if can transfer out asset
        #     "updateTime": 0,
        #     "totalInitialMargin": "0.00000000",    # total initial margin required with current mark price(useless with isolated positions), only for USDT asset
        #     "totalMaintMargin": "0.00000000",     # total maintenance margin required, only for USDT asset
        #     "totalWalletBalance": "23.72469206",     # total wallet balance, only for USDT asset
        #     "totalUnrealizedProfit": "0.00000000",   # total unrealized profit, only for USDT asset
        #     "totalMarginBalance": "23.72469206",     # total margin balance, only for USDT asset
        #     "totalPositionInitialMargin": "0.00000000",    # initial margin required for positions with current mark price, only for USDT asset
        #     "totalOpenOrderInitialMargin": "0.00000000",   # initial margin required for open orders with current mark price, only for USDT asset
        #     "totalCrossWalletBalance": "23.72469206",      # crossed wallet balance, only for USDT asset
        #     "totalCrossUnPnl": "0.00000000",      # unrealized profit of crossed positions, only for USDT asset
        #     "availableBalance": "23.72469206",       # available balance, only for USDT asset
        #     "maxWithdrawAmount": "23.72469206"     # maximum amount for transfer out, only for USDT asset
        #     ...
        # }
        feeTier = self.safe_integer(accountInfo, 'feeTier')
        feeTiers = self.fees['trading']['tiers']
        maker = feeTiers['maker'][feeTier][1]
        taker = feeTiers['taker'][feeTier][1]
        for i in range(0, len(marketSymbols)):
            symbol = marketSymbols[i]
            fees[symbol] = {
                'info': {
                    'feeTier': feeTier,
                },
                'symbol': symbol,
                'maker': maker,
                'taker': taker,
            }
        return fees

    def transfer_in(self, code, amount, params={}):
        # transfer from spot wallet to usdm futures wallet
        return self.futuresTransfer(code, amount, 1, params)

    def transfer_out(self, code, amount, params={}):
        # transfer from usdm futures wallet to spot wallet
        return self.futuresTransfer(code, amount, 2, params)
